pub enum ReinitUserCryptoError {
NotUnlocked,
InvalidAccountCryptographicState,
LocalMigrationFailed,
InvalidUpgradeToken,
CryptoInitialization,
StateBridgeNotRegistered,
}Expand description
Errors that can occur when re-initializing user cryptography state.
Variants
NotUnlocked
The SDK is not in an unlocked state, so it cannot re-initialize user crypto.
InvalidAccountCryptographicState
The provided account cryptographic state is not V2. Re-initialization is only supported for upgrading to V2 encryption.
LocalMigrationFailed
The local migrations (pin key and local user data key) that runs as part of the V1->V2 upgrade failed, likely due to missing state or keys that should be present during the upgrade process. Clients should deconstruct the SDK and initialize a fresh instance to recover.
InvalidUpgradeToken
The provided upgrade token was invalid, such as not decrypting properly with the active user key, or containing unexpected data.
CryptoInitialization
An error occurred during the cryptographic operations to re-initialize user crypto.
StateBridgeNotRegistered
The SDK does not have a state bridge registered, which is required to perform V1->V2 local data migrations.